@@ -29,7 +29,7 @@ taxname.abbr <- function(x, hybrid=FALSE, species=FALSE, cf=FALSE, ...) {
     x <- sub('\ nothosubsp[.]' , '\ nothossp.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ nothossp[.]' , '\ nssp.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ nothovar[.]' , '\ nvar.', x, perl=TRUE, useBytes=TRUE)
-    if(hybrid) {
+  if(hybrid) {
       x <- sub('\ x.' , '\ ', x, perl=TRUE, useBytes=TRUE)
       x <- sub('\ nssp[.]' , '\ ssp.', x, perl=TRUE, useBytes=TRUE)
       x <- sub('\ nvar[.]' , '\ var.', x, perl=TRUE, useBytes=TRUE)
@@ -56,6 +56,7 @@ taxname.simplify <- function(x, genus=TRUE, epithet=TRUE, hybrid=TRUE, ...) {
     x <- gsub('\U00CF', 'i', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('ii', 'i', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('nn', 'n', x, perl=TRUE, useBytes=TRUE)
+    x <- gsub('fa', 'pha', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('ph', 'p', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('rh', 'h', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('th', 't', x, perl=TRUE, useBytes=TRUE)
@@ -107,30 +108,30 @@ return(x)
 TCS.replace <- function(x) {
   x <- toupper(x)
 ## Turboveg & ## Florkart Germany (BfN lists)
-x <- replace(x, x %in% c('SPECIES_NR', 'TAXNR', 'NAMNR', 'NAMEID'), 'TaxonUsageID')
-x <- replace(x, x %in% c('ABBREVIAT','TAXONANME','TAXON','TAXNAME'), 'TaxonName')
-x <- replace(x, x %in% c('VALID_NR', 'SIPNR', 'SYNNAMEID'), 'TaxonConceptID')
-x <- replace(x, x %in% c('VALID_NAME'), 'TaxonConcept')
-x <- replace(x, x %in% c('AGG', 'AGGNR', 'NAMEPARENTID'), 'IsChildTaxonOfID')
-x <- replace(x, x %in% c('AGG_NAME'), 'IsChildTaxonOf')
-x <- replace(x, x %in% c('SECUNDUM'), 'AccordingTo')
-x <- replace(x, x %in% c('NATIVENAME', "COMMONNAME"), 'VernacularName')
-x <- replace(x, x %in% c('CLASSIFICA'), 'Classification')
-x <- replace(x, x %in% c('RANG', 'RANK', "TAXONOMICRANK"), 'TaxonRank')
+  x <- replace(x, x %in% c('SPECIES_NR', 'TAXNR', 'NAMNR', 'NAMEID', 'TAXONUSAGEID'), 'TaxonUsageID')
+  x <- replace(x, x %in% c('ABBREVIAT','TAXONNAME','TAXON','TAXNAME'), 'TaxonName')
+  x <- replace(x, x %in% c('VALID_NR', 'SIPNR', 'SYNNAMEID', 'TAXONCONCEPTID'), 'TaxonConceptID')
+  x <- replace(x, x %in% c('VALID_NAME', 'TAXONCONCEPT'), 'TaxonConcept')
+  x <- replace(x, x %in% c('AGG', 'AGGNR', 'NAMEPARENTID', 'ISCHILDTAXONOFID'), 'IsChildTaxonOfID')
+  x <- replace(x, x %in% c('AGG_NAME', 'ISCHILDTAXONOF'), 'IsChildTaxonOf')
+  x <- replace(x, x %in% c('SECUNDUM', 'ACCORDINGTO'), 'AccordingTo')
+  x <- replace(x, x %in% c('NATIVENAME', "COMMONNAME", 'VERNACULARNAME'), 'VernacularName')
+  x <- replace(x, x %in% c('CLASSIFICA', 'CLASSIFICATION'), 'Classification')
+  x <- replace(x, x %in% c('RANG', 'RANK', "TAXONOMICRANK", 'TAXONRANK'), 'TaxonRank')
 
 ## ESveg
-  x <- replace(x, x=="TAXONCODE", 'TaxonUsageID')
-  x <- replace(x, x=="OBSERVATIONCODE", "RELEVE_NR")
-  x <- replace(x, x=="OBSERVATIONID", "RELEVE_NR")
-  x <- replace(x, x=="STRATUMCODE", "LAYER")
-  x <- replace(x, x=="STRATUM", "LAYER")
-  x <- replace(x, x=="PERCENTAGE_MEAN", "COVER_PERC")
-  x <- replace(x, x=="COVERPERCENT", "COVER_PERC")
+  x <- replace(x, x %in% c("TAXONCODE"), 'TaxonUsageID')
+  x <- replace(x, x %in% c("OBSERVATIONCODE"), "RELEVE_NR")
+  x <- replace(x, x %in% c("OBSERVATIONID"), "RELEVE_NR")
+  x <- replace(x, x %in% c("STRATUMCODE"), "LAYER")
+  x <- replace(x, x %in% c("STRATUM"), "LAYER")
+  x <- replace(x, x %in% c("PERCENTAGE_MEAN"), "COVER_PERC")
+  x <- replace(x, x %in% c("COVERPERCENT"), "COVER_PERC")
 
 ## CDM
-  x <- replace(x, x=='TAXON', 'TaxonName')
-  x <- replace(x, x=='SYNUUID', 'TaxonUsageID')
-  x <- replace(x, x=='ACCTAXONID', 'TaxonConceptID')
+  x <- replace(x, x %in% c('TAXON'), 'TaxonName')
+  x <- replace(x, x %in% c('SYNUUID'), 'TaxonUsageID')
+  x <- replace(x, x %in% c('ACCTAXONID'), 'TaxonConceptID')
   return(x)
 }
 
