@@ -1,7 +1,7 @@
 if(getRversion() >= "2.15.1")  utils::globalVariables(c("DoWritedbf"))
 
 tv.write <- function(x, site, db, name, cover=c('code','perc'), overwrite = FALSE, iconv="CP437", newTvAdmin = FALSE, ...) {
-  if(missing(db)) stop('Name of original database is missing.')
+  if(missing(db)) warning('Name of original database is necessary to process TvAdmin.dbf, remarks.dbf and tvwin.set')
   cover <- match.arg(cover)
   if('veg' %in% class(x)) {
     X <- reShape.veg(x, ...)
@@ -27,12 +27,20 @@ tv.write <- function(x, site, db, name, cover=c('code','perc'), overwrite = FALS
     site[is.na(site[,i]),i] <- ''
     site[,i] <- iconv(site[,i], '', iconv)
   }
+### Add obligatory fields
+# obl <- c('RELEVE_NR','COUNTRY','REFERENCE','TABLE_NR','NR_IN_TAB','COVERSCALE','PROJECT','AUTHOR','DATE','SYNTAXON','SURF_AREA','UTM','ALTITUDE','EXPOSITION','INCLINATIO','COV_TOTAL','COV_TREES','COV_SHRUBS','COV_HERBS','COV_MOSSES','COV_LICHEN','COV_ALGAE','COV_LITTER','COV_WATER','COV_ROCK','TREE_HIGH','TREE_LOW','SHRUB_HIGH','SHRUB_LOW','HERB_HIGH','HERB_LOW','HERB_MAX','CRYPT_HIGH','MOSS_IDENT','LICH_IDENT','REMARKS')
+obl <- c('RELEVE_NR','COUNTRY','REFERENCE','TABLE_NR','NR_IN_TAB','COVERSCALE','DATE','SURF_AREA','UTM','ALTITUDE','EXPOSITION','INCLINATIO','COV_TOTAL')
+for(m in obl[!obl %in% names(site)]) {
+  site[,m] <- ''
+}
 
 ### Write
   dir.create(file.path(options('tv_home'), 'Data', name), showWarnings = if(overwrite) FALSE else TRUE)
   write.dbf(site, file.path(options('tv_home'), 'Data', name, 'tvhabita.dbf'))
   write.dbf(X, file.path(options('tv_home'), 'Data', name, 'tvabund.dbf'))
  # Remarks
+ if(!missing(db)) {
+  # print(file.path(options('tv_home'), 'Data', db[1], 'remarks.dbf'))
   remarks <- read.dbf(file.path(options('tv_home'), 'Data', db[1], 'remarks.dbf'), as.is=TRUE)
   if(length(db) > 1) 
     for(n in 2:length(db)) remarks <- rbind(remarks, read.dbf(file.path(options('tv_home'), 'Data', db[n], 'remarks.dbf'), as.is=TRUE))
@@ -42,49 +50,22 @@ tv.write <- function(x, site, db, name, cover=c('code','perc'), overwrite = FALS
   suppressWarnings(write.dbf(remarks, file.path(options('tv_home'), 'Data', name, 'remarks.dbf')))
   options(op)
  # TvAdmin
-  TvAdmin <- read.dbf(file.path(options('tv_home'), 'Data', db[1], 'TvAdmin.dbf'))
+  TvAdmin <- read.dbf(file.path(options('tv_home'), 'Data', db[1], 'TvAdmin.dbf'), as.is = TRUE)
   if(length(db) > 1) 
     for(n in 2:length(db)) TvAdmin <- rbind(TvAdmin, read.dbf(file.path(options('tv_home'), 'Data', db[n], 'TvAdmin.dbf')))
   TvAdmin <- TvAdmin[TvAdmin$RELEVE_NR %in% site$RELEVE_NR,]
   TvAdmin$MOD_USER[is.na(TvAdmin$MOD_USER)] <- Sys.getenv('USER')
-#  TvAdmin$MOD_DATE[is.na(TvAdmin$MOD_DATE)] <- format(Sys.Date(), "%D")
+  TvAdmin$MOD_DATE[is.na(TvAdmin$MOD_DATE)] <- format(Sys.Date())
   write.dbf(TvAdmin, file.path(options('tv_home'), 'Data', name, 'TvAdmin.dbf'))
 
   if(!any(db == name)) file.copy(from = file.path(options('tv_home'), 'Data', db[1], 'tvwin.set'), to=file.path(options('tv_home'),'Data', name, 'tvwin.set'), overwrite = overwrite)
-
+ }
   cat('Turboveg database', name, 'written to', file.path(options('tv_home'), 'Data', name),'\n')
 
 if(newTvAdmin) {
-  # tvadmin <- read.dbf(file.path(options('tv_home'), 'Data', db, 'TvAdmin.dbf'))
-  # RELEVE_NR,N,6,0  SOURCE_DB,C,38	GUID,C,38	CREAT_USER,C,25	CREAT_DATE,D	MOD_USER,C,25	MOD_DATE,D	NDFF_QUAL,N,1,0
-  tvadmin <- data.frame(RELEVE_NR=site$RELEVE_NR, SOURCE_DB=db,	GUID=uuid(n=nrow(site)),	CREAT_USER=Sys.getenv('USER'), CREAT_DATE=Sys.Date(), MOD_USER=Sys.getenv('USER'),	MOD_DATE=Sys.Date(), NDFF_QUAL=as.integer(0))
-  write.dbf(tvadmin, file.path(options('tv_home'),'Data', name, 'TvAdmin.dbf'))
-  #write.tvdbf(tvadmin, file.path(options('tv_home'),'Data', name, 'TvAdmin.dbf'), dec=c(6,38,38,25,10,25,10,1))
+  cat('If you want to create a new TvAdmin.dbf, please install a library with uuid capabilities (e.g. UUIDgenerate from package uuid, or uuid.gen from dplR):\n')
+  cat("tvadmin <- data.frame(RELEVE_NR=site$RELEVE_NR, SOURCE_DB=db,  GUID=replicate(nrow(site), UUIDgenerate()),	CREAT_USER=Sys.getenv('USER'), CREAT_DATE=Sys.Date(), MOD_USER=Sys.getenv('USER'),	MOD_DATE=Sys.Date(), NDFF_QUAL=as.integer(0))\n")
+  cat("write.dbf(tvadmin, file.path(options('tv_home'),'Data', db, 'TvAdmin.dbf'))")
 }
 }
 
-## Version 4 UUIDs have the form:
-##    xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx
-##    where x is any hexadecimal digit and
-##    y is one of 8, 9, A, or B
-##    f47ac10b-58cc-4372-a567-0e02b2c3d479
-uuid <- function(uppercase=FALSE, n=1) {
-  
-  hex_digits <- c(as.character(0:9), letters[1:6])
-  hex_digits <- if (uppercase) toupper(hex_digits) else hex_digits
-  
-  y_digits <- hex_digits[9:12]
-  u <- vector(length = n)
-  for(i in 1:n) {
-  u[i] <- paste(
-    paste0(sample(hex_digits, 8), collapse=''),
-    paste0(sample(hex_digits, 4), collapse=''),
-    paste0('4', sample(hex_digits, 3), collapse=''),
-    paste0(sample(y_digits,1),
-           sample(hex_digits, 3),
-           collapse=''),
-    paste0(sample(hex_digits, 12), collapse=''),
-    sep='-')
-  }
-  return(u)
-}
