@@ -3,6 +3,7 @@ library(knitr)
 opts_chunk$set(
 concordance=TRUE,
 results="tex")
+options(results = 'tex') # for pqR
 
 ## ----prep, echo=FALSE---------------------------------------------------------------------------------------
 library(knitr)
@@ -42,9 +43,10 @@ db <- 'taxatest'
 ## ----path, results='hide', echo=FALSE-----------------------------------------------------------------------
 
 ## ----meta, eval=FALSE---------------------------------------------------------------------------------------
-#  tv.metainfo(db)
+#  tv.metadata(db)
 
 ## ----obs----------------------------------------------------------------------------------------------------
+getOption('tv_home')
 obs.tax <- tv.obs(db)
 # Adding species names
 species <- tax('all')
@@ -53,7 +55,7 @@ head(obs.tax[,c('RELEVE_NR','TaxonUsageID','COVER_CODE','LAYER','TaxonName')])
 
 ## ----taxval, eval=TRUE--------------------------------------------------------------------------------------
 obs.tax$OriginalName <- obs.tax$TaxonName
-obs.taxval <- taxval(obs.tax, db=db, mono='lower', maxtaxlevel='AGG', sink=FALSE)
+obs.taxval <- taxval(obs.tax, db=db, mono='lower', maxtaxlevel='AGG', interactive=FALSE)
 
 ## ----Taxon--------------------------------------------------------------------------------------------------
 obs.taxval$OriginalName <- obs.taxval$TaxonName
@@ -61,7 +63,7 @@ obs.taxval$TaxonName <-  species$TaxonName[match(obs.taxval$TaxonUsageID, specie
 obs.taxval[!duplicated(obs.taxval$OriginalName),c('RELEVE_NR', 'COVER_CODE', 'TaxonName', 'OriginalName')]
 
 ## ----coarsen, eval=TRUE, results='hide'---------------------------------------------------------------------
-tmp <- taxval(obs.tax, refl='GermanSL 1.3', ag='adapt', rank='FAM', sink=FALSE)
+tmp <- taxval(obs.tax, refl='GermanSL 1.3', ag='adapt', rank='FAM')
 tmp$newTaxon <- tax(tmp$TaxonUsageID, refl='GermanSL 1.3')$TaxonName
 
 ## ----print.coarsen------------------------------------------------------------------------------------------
@@ -89,7 +91,8 @@ names(tv.veg(db, tax=FALSE, pseudo=comb, quiet=TRUE))
 
 ## ----layer, results='hide', warning=FALSE-------------------------------------------------------------------
 data(lc.1)
-veg <- tv.veg(db, lc = "sum", pseudo = list(lc.1, 'LAYER'), dec = 1, quiet=TRUE)
+veg <- tv.veg(db, lc = "sum", pseudo = list(lc.1, 'LAYER'), dec = 1, check.critical = FALSE)
+
 
 ## ----layerdiff----------------------------------------------------------------------------------------------
 veg[,1:10]
@@ -103,7 +106,6 @@ obs.tax$TaxonUsageID <- replace(obs.tax$TaxonUsageID,
     match(taxon.repl$old, obs.tax$TaxonUsageID), taxon.repl$new)
 
 ## ----comb.spec, eval=TRUE-----------------------------------------------------------------------------------
-veg <- tv.veg('taxatest', quiet=TRUE)
 comb.species(veg, sel=c('QUERROB','QUERROB.Tree'))
 
 ## ----site.echo, eval=TRUE-----------------------------------------------------------------------------------
@@ -126,10 +128,12 @@ levels(clust) <- c('dry.ld','dry.hd', 'wet.hd','wet.ld')
 
 ## ----syntab.mupa--------------------------------------------------------------------------------------------
 require(indicspecies)
-traits <- tv.traits()
-trait <- data.frame(EIV_F = traits$OEK_F, EIV_N = traits$OEK_N)
-rownames(trait) <- traits$ABBREVIAT
 st <- syntab(elbaue, clust, mupa=TRUE)
+# Print Ellenberg indicator values for soil moisture and nutrient demand
+traits <- tv.traits()
+trait <- traits[traits$LETTERCODE %in% names(elbaue), ]
+rownames(trait) <- trait$LETTERCODE
+trait <- trait[,c('OEK_F', 'OEK_N')]
 print(st, limit=30, trait=trait)
 
 ## ----nmds, quiet=TRUE, results='hide', eval=TRUE------------------------------------------------------------
@@ -137,9 +141,11 @@ print(st, limit=30, trait=trait)
 library(vegan)
 veg.nmds <- metaMDS(elbaue, distance = "bray", trymax = 5, autotransform =FALSE, 
      noshare = 1, expand = TRUE, trace = 2)
-mT.F <- meanTraits('OEK_F', elbaue)
-mT.N <- meanTraits('OEK_N', elbaue)
-env <- envfit(veg.nmds, data.frame(mT.F,mT.N))
+eco <- tv.traits()
+eco$OEK_F <- as.numeric(eco$OEK_F)
+F <- isc(elbaue, eco, 'OEK_F', method = 'mean')
+N <- isc(elbaue, eco, 'OEK_N', method = 'mean')
+env <- envfit(veg.nmds, data.frame(F, N))
 
 ## ----nmdsplotfun, quiet=TRUE, results='hide'----------------------------------------------------------------
 library(labdsv)
@@ -164,5 +170,5 @@ nmds.plot <- function(ordi, site, var1, var2, disp, plottitle =  'NMDS', env = N
 
 ## ----nmdsplot, quiet=TRUE, results='hide', eval=TRUE, warning=FALSE-----------------------------------------
 nmds.plot(veg.nmds, elbaue.env, disp='species', var1="MGL", var2="SDGL", env=env, 
-        plottitle = 'NMDS of Elbaue floodplain vegetation')
+        plottitle = 'Elbaue floodplain dataset')
 
